@@ -1,9 +1,9 @@
 """ This file is licensed under GPLv3, see https://www.gnu.org/licenses/ """
 
 from multiprocessing.pool import ThreadPool
-from typing import List, Optional, Dict, Iterable, Any
+from typing import List, Optional, Dict, Sequence, Any
 
-from .i18n import _
+from .i18n import translate
 from .core import PackageSource, InstallInfo, ComparableType
 from .version import VersionMatcher
 from .pacman import (
@@ -109,7 +109,7 @@ class InstallInfoFetcher(ComparableType):
         return list(set(_aur_deps_names))
 
     @property
-    def all_install_info(self) -> Iterable[List[InstallInfo]]:
+    def all_install_info(self) -> Sequence[List[InstallInfo]]:
         return (
             self.repo_packages_install_info,
             self.new_repo_deps_install_info,
@@ -138,7 +138,7 @@ class InstallInfoFetcher(ComparableType):
                     del self.aur_deps_relations[aur_pkg_name]
         return list(set(already_discarded))
 
-    def get_all_packages_info(self) -> None:  # pylint:disable=too-many-branches
+    def get_all_packages_info(self) -> None:
         """
         Retrieve info (`InstallInfo` objects) of packages
         which are going to be installed/upgraded and their dependencies
@@ -177,7 +177,7 @@ class InstallInfoFetcher(ComparableType):
 
         self.mark_dependent()
 
-    def _get_repo_pkgs_info(  # pylint: disable=too-many-locals
+    def _get_repo_pkgs_info(
             self, pkg_lines: List[str], extra_args: Optional[List[str]] = None
     ) -> List[InstallInfo]:
         if not pkg_lines:
@@ -440,13 +440,14 @@ class InstallInfoFetcher(ComparableType):
                 srcinfo = SrcInfo(pkgbuild_path=path, package_name=pkg_name)
                 aur_pkg = AURPackageInfo.from_srcinfo(srcinfo)
                 if pkg_name in aur_updates_install_info_by_name:
-                    raise Exception(_(f"{pkg_name} already added to the list"))
+                    raise Exception(translate(f"{pkg_name} already added to the list"))
                 local_pkg = local_pkgs.get(pkg_name)
                 aur_updates_install_info_by_name[pkg_name] = InstallInfo(
                     name=pkg_name,
                     current_version=local_pkg.version if local_pkg else ' ',
                     new_version=aur_pkg.version,
                     description=aur_pkg.desc,
+                    maintainer='local user',
                     package=aur_pkg,
                     pkgbuild_path=path,
                 )
@@ -461,7 +462,7 @@ class InstallInfoFetcher(ComparableType):
             else:
                 raise TypeError()
         if all_aur_pkgs:
-            print_stdout(_("Resolving AUR dependencies..."))
+            print_stdout(translate("Resolving AUR dependencies..."))
         try:
             self.aur_deps_relations = find_aur_deps(all_aur_pkgs)
         except DependencyVersionMismatch as exc:
@@ -496,7 +497,7 @@ class InstallInfoFetcher(ComparableType):
                 package=aur_pkg,
             ))
 
-    def mark_dependent(self) -> None:  # pylint: disable=too-many-locals
+    def mark_dependent(self) -> None:
         """
         update packages' install info to show deps in prompt:
         """
